.. module:: enaml.widgets.menu_bar

======================
enaml.widgets.menu_bar
======================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    MenuBar


.. autoclass:: MenuBar
